<script setup>
import { getCurrentInstance, ref, computed, reactive } from 'vue';
import { useRouter } from "vue-router";
import { get, post, postBlob } from '@/utils/request.js'
import { message, Modal } from 'ant-design-vue';
import { logout } from '@/config.js';
import EditView from './edit.vue'
import { formatMessage } from '@/utils/localeUtils.js';
const context = getCurrentInstance()?.appContext.config.globalProperties;

const router = useRouter();

const TABLE_KEY = 'table-tag';
let currentPage = 1;
let pageSize = 10;
const searchInput = ref("")
const editChild = ref(null)

const state = reactive({
  selectedRowKeys: [],
  loading: false,
});

let tableData = ref([]);
getPage();

const columns = [
  // {
  //     title: formatMessage('db.man_tag.uuid', '编号'),
  //     dataIndex: 'uuid',
  //     width: 140,
  //     ellipsis: true,
  // },
  {
    title: formatMessage('db.man_tag.name', '名称'),
    dataIndex: 'name',
    width: 140,
    ellipsis: true,
  },
  {
    title: formatMessage('db.man_tag.flag', '标识'),
    dataIndex: 'flag',
    width: 140,
    ellipsis: true,
  },
  {
    title: formatMessage('db.man_tag.status', '状态'),
    dataIndex: 'status$',
    width: 140,
    ellipsis: true,
  },
  // {
  //     title: formatMessage('db.man_tag.create_time', '添加时间'),
  //     dataIndex: 'createTime$',
  //     width: 140,
  //     ellipsis: true,
  // },
  // {
  //     title: formatMessage('db.man_tag.create_by', '添加人员'),
  //     dataIndex: 'createBy$',
  //     width: 140,
  //     ellipsis: true,
  // },
  // {
  //     title: formatMessage('db.man_tag.update_time', '修改时间'),
  //     dataIndex: 'updateTime$',
  //     width: 140,
  //     ellipsis: true,
  // },
  // {
  //     title: formatMessage('db.man_tag.update_by', '修改人员'),
  //     dataIndex: 'updateBy$',
  //     width: 140,
  //     ellipsis: true,
  // },
  {
    title: formatMessage('db.man_tag.memo', '备注'),
    dataIndex: 'memo',
    width: 140,
    ellipsis: true,
  },
  // {
  //     title: formatMessage('db.man_tag.parent_id', '父级'),
  //     dataIndex: 'parentId',
  //     width: 140,
  //     ellipsis: true,
  // },
  // {
  //     title: formatMessage('db.man_tag.parent_name', '父级名称'),
  //     dataIndex: 'parentName',
  //     width: 140,
  //     ellipsis: true,
  // },
  // {
  //     title: formatMessage('db.man_tag.path', '关联路径'),
  //     dataIndex: 'path',
  //     width: 140,
  //     ellipsis: true,
  // },
  // {
  //     title: formatMessage('db.man_tag.path_name', '关联路径名'),
  //     dataIndex: 'pathName',
  //     width: 140,
  //     ellipsis: true,
  // },
  {
    title: formatMessage('db.man_tag.type', '类型'),
    dataIndex: 'type$',
    width: 140,
    ellipsis: true,
  },
  {
    title: formatMessage('db.man_tag.count', '数量'),
    dataIndex: 'count',
    width: 140,
    ellipsis: true,
  },
  {
    title: formatMessage('db.man_tag.level', '等级'),
    dataIndex: 'level',
    width: 140,
    ellipsis: true,
  },
  {
    title: formatMessage('db.man_tag.sort', '排序'),
    dataIndex: 'sort',
    width: 140,
    ellipsis: true,
  },

  {
    title: formatMessage('common.operation', '操作'),
    name: 'oper',
    dataIndex: 'oper',
    key: 'oper',
    width: 140,
  },
];


const hasSelected = computed(() => state.selectedRowKeys.length > 0);
const start = () => {
  state.loading = true;
  // ajax request after empty completing
  setTimeout(() => {
    state.loading = false;
    state.selectedRowKeys = [];
  }, 1000);
};
const onSelectChange = selectedRowKeys => {
  // console.log('selectedRowKeys changed: ', selectedRowKeys);
  state.selectedRowKeys = selectedRowKeys;
};

function getPage() {
  state.loading = true;
  post('/api/tag/tree', {
    current: currentPage,
    pageSize: pageSize,
    condition: searchInput.value
  }).then((resp) => {
    let result = resp.data;
    if (result.code == 200) {
      let data = result.data;
      tableData.value = data;

      editChild.value.treeData = [{
        id: 0,
        name: '全部',
        children: data
      }];

      state.loading = false;
    } else if (result.code === 401) {
      message.error(result.msg);
      logout()
    } else {
      message.error(result.msg);
    }
  })
}

const handleEdit = (item) => {
  editChild.value.open = true;
  editChild.value.formData = item == null ? editChild.value.initFormData : JSON.parse(JSON.stringify(item));
  editChild.value.isSave = item == null;
}

const handleDel = (rows) => {
  Modal.confirm({
    title: formatMessage('page.delete', '删除'),
    content: formatMessage('page.delete.confirm', '确定删除该项吗？'),
    maskClosable: true,
    onOk: async () => {
      const hide = message.loading(formatMessage('common.loading', '请求中'));
      try {
        post('/api/tag/remove/' + rows.map((row) => row.id).join(','), {}).then(resp => {
          let result = resp.data;
          if (result.code === 200) {
            message.success(result.msg);
          } else {
            message.error(result.msg);
          }
          getPage()
          hide()
        })
      } catch (error) {
        message.error(formatMessage('common.fail', '请求失败'));
      }
    },
  });
}

const handleExport = async (intl) => {
  postBlob('/api/tag/export', {}).then(result => {
    const blob = new Blob([result.data], { type: 'application/vnd.ms-excel' });
    window.location.href = window.URL.createObjectURL(blob);
    return true;
  })
};

const onSearch = () => {
  // console.log('search');
  getPage()
}

const onPageChange = (page, size) => {
  currentPage = page;
  pageSize = size;
  getPage();
}

function handleTableReload(value) {
  getPage()
}

</script>

<script>
export default {
  name: '归类管理'
}
</script>

<template>
  <div>
    <EditView ref="editChild" @tableReload="handleTableReload" />
    <div class="table-header">
      <a-input-search v-model:value="searchInput" :placeholder="formatMessage('page.input', '请输入')"
        style="width: 200px;" @search="onSearch" />
      <div class="table-header-right">
        <a-button @click="handleEdit(null)" type="primary">{{ formatMessage('page.add', '添加') }}</a-button>
        <a-button @click="handleExport">{{ formatMessage('page.export', '导出') }}</a-button>
      </div>
    </div>

    <a-table :row-selection="{ selectedRowKeys: state.selectedRowKeys, onChange: onSelectChange }"
      :data-source="tableData" :defaultExpandAllRows="false" key="menu" rowKey="id" :loading="state.loading">
      <a-table-column :title="formatMessage('db.man_tag.name', '名称')" key="name" data-index="name" />
      <a-table-column :title="formatMessage('db.man_tag.flag', '标识')" key="flag" data-index="flag" />
      <a-table-column :title="formatMessage('db.man_tag.status', '状态')" key="status$" data-index="status$" />
      <a-table-column :title="formatMessage('db.man_tag.memo', '备注')" key="memo" data-index="memo" />
      <a-table-column :title="formatMessage('db.man_tag.count', '数量')" key="count" data-index="count" />
      <a-table-column :title="formatMessage('db.man_tag.level', '等级')" key="level" data-index="level" />
      <a-table-column :title="formatMessage('db.sys_menu.sort', '排序')" key="sort" data-index="sort" />
      <a-table-column :title="formatMessage('db.sys_menu.status', '状态')" key="status$" data-index="status$" />
      <a-table-column :title="formatMessage('common.operation', '操作')" key="oper" data-index="oper">
        <template #default="{ record }">
          <div style="display: flex;justify-content: space-evenly;">
            <a-button type="link" primary @click="handleEdit(record)">{{ formatMessage('page.edit', '编辑') }}</a-button>
            <a-button type="link" danger @click="handleDel([record])">{{ formatMessage('page.delete', '删除')
              }}</a-button>
          </div>
        </template>
      </a-table-column>
    </a-table>
  </div>
</template>

<style></style>
